from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.anchor import image_template

docs = [
    {
        "path": "../docs/anchor/body/v1.md",
        "items": ImageItems(
            {
                image_template.format("20251204_144010.jpg"): "",
                image_template.format("20251204_144014.jpg"): "",
                image_template.format("20251204_144017.jpg"): "",
                image_template.format("20251204_144021.jpg"): "",
                image_template.format("20251204_144024.jpg"): "",
                image_template.format("20251204_144031.jpg"): "",
                image_template.format("20251205_175953.jpg"): "",
            }
        ),
    },
]
